@@ -4,7 +4,7 @@ if Gem::Version.new(RUBY_VERSION.dup) < Gem::Version.new("1.9.3")
   raise LoadError, _("Puppet %{version} requires ruby 1.9.3 or greater.") % { version: Puppet.version }
 end
 
-Puppet::OLDEST_RECOMMENDED_RUBY_VERSION = '2.1.0'
+Puppet::OLDEST_RECOMMENDED_RUBY_VERSION = '2.3.0'
 
 # see the bottom of the file for further inclusions
 # Also see the new Vendor support - towards the end
@@ -42,11 +42,8 @@ module Puppet
   require 'puppet/environments'
 
   class << self
-    Puppet::GettextConfig.create_text_domain('production')
-    locale_dir = Puppet::GettextConfig.puppet_locale_path
-    if Puppet::GettextConfig.load_translations('puppet', locale_dir, Puppet::GettextConfig.translation_mode(locale_dir))
-      Puppet::GettextConfig.set_locale(Locale.current.language)
-    end
+    Puppet::GettextConfig.setup_locale
+    Puppet::GettextConfig.create_default_text_domain
 
     include Puppet::Util
     attr_reader :features
